@@ -4,7 +4,8 @@
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
-  License version 2.1 as published by the Free Software Foundation.
+  License as published by the Free Software Foundation; either
+  version 2.1 of the License, or (at your option) any later version.
 
   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -90,19 +91,12 @@ grn_table_apply_expr(grn_ctx *ctx,
 }
 
 grn_id
-grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
+grn_table_find_reference_object_raw(grn_ctx *ctx, grn_id table_id)
 {
-  grn_id table_id;
   grn_id reference_object_id = GRN_ID_NIL;
 
   GRN_API_ENTER;
 
-  if (!grn_obj_is_table(ctx, table)) {
-    GRN_API_RETURN(GRN_ID_NIL);
-  }
-
-  table_id = DB_OBJ(table)->id;
-
   GRN_DB_EACH_SPEC_BEGIN(ctx, cursor, id, spec)
   {
     if (id == table_id) {
@@ -139,6 +133,22 @@ grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
   GRN_API_RETURN(reference_object_id);
 }
 
+grn_id
+grn_table_find_reference_object(grn_ctx *ctx, grn_obj *table)
+{
+  GRN_API_ENTER;
+
+  if (!grn_obj_is_table(ctx, table)) {
+    GRN_API_RETURN(GRN_ID_NIL);
+  }
+
+  grn_id table_id = DB_OBJ(table)->id;
+  grn_id reference_object_id =
+    grn_table_find_reference_object_raw(ctx, table_id);
+
+  GRN_API_RETURN(reference_object_id);
+}
+
 static void
 grn_table_copy_array(grn_ctx *ctx, grn_obj *from, grn_obj *to)
 {
@@ -278,7 +288,7 @@ grn_table_copy_different(grn_ctx *ctx, grn_obj *from, grn_obj *to)
 
     key_size = grn_table_cursor_get_key(ctx, cursor, &key);
     grn_bulk_write(ctx, &from_key_buffer, key, (size_t)key_size);
-    cast_rc = grn_obj_cast(ctx, &from_key_buffer, &to_key_buffer, GRN_FALSE);
+    cast_rc = grn_obj_cast(ctx, &from_key_buffer, &to_key_buffer, false);
     if (cast_rc != GRN_SUCCESS) {
       char from_name[GRN_TABLE_MAX_KEY_SIZE];
       int from_name_size;
